==> subtitleeditor_0.10.1.orig.tar.gz: subtitleeditor-0.10.1/src/SubtitleMicroDVD.cc <==
/*
 *	subtitle editor
 *
 *	http://kitone.free.fr/subtitleeditor/
 *
 *	Copyright @ 2005-2006, kitone
 *
 *	Contact: kitone at free dot fr
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public
 *	License as published by the Free Software Foundation; either
 *	version 2 of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public
 *	License along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 *
 *	See gpl.txt for more information regarding the GNU General Public License.
 *
 *
 *	\file
 *	\brief 
 *	\author kitone (kitone at free dot fr)
 */

#include "SubtitleMicroDVD.h"
#include <iostream>
#include <fstream>
#include <glibmm/ustring.h>
#include "utility.h"

/*
 *
 */
Glib::ustring SubtitleMicroDVD::get_name()
{
	return "MicroDVD";
}

/*
 *
 */
Glib::ustring SubtitleMicroDVD::get_extension()
{
	return "sub";
}

/*
 *
 */
bool SubtitleMicroDVD::check(const std::string &line)
{
	static RegEx ex("^\\{[0-9]+\\}\\{[0-9]+\\}");

	return ex.exec(line);
}


/*
 *
 */
SubtitleMicroDVD::SubtitleMicroDVD(Document* doc)
:m_model(doc->m_subtitleModel)
{
}

/*
 *
 */
SubtitleMicroDVD::~SubtitleMicroDVD()
{
}


/*
 *
 */
bool SubtitleMicroDVD::open(const Glib::ustring &filename, const Glib::ustring &encoding)
{
	SubtitleFormat::open(filename, encoding);

	debug_msg("SubtitleMicroDVD::open > start");
	
	std::ifstream file(filename.c_str());

	if(!file)
	{
		throw SubtitleException("SubtitleMicroDVD", _("I can't open this file."));
	}

	SubtitleColumnRecorder column;

	unsigned int start=0, end=0;

#warning "fixme > FPS convert"

	double fps = 23.976;
	
	std::string line;
	while(!file.eof() && std::getline(file, line))
	{
		if(sscanf(line.c_str(), "{%d}{%d}", &start, &end) > 0)
		{
			std::string::size_type a = line.find('}');
			std::string::size_type b = line.find('}', a+1);
			
			std::string text = line.substr(b+1, line.size());

			Gtk::TreeIter iter = m_model->append();

			(*iter)[column.text]	= check_end_char(charset_to_utf8(text));

			(*iter)[column.start] = SubtitleTime((long int)(start*fps)).str();
			(*iter)[column.end] = SubtitleTime((long int)(end*fps)).str();
		}
	}

	file.close();

	debug_msg("SubtitleMicroDVD::open > finish");
	return true;
}

/*
 *
 */
bool SubtitleMicroDVD::save(const Glib::ustring &filename, const Glib::ustring &encoding)
{
	debug_msg("SubtitleMicroDVD::save > start");

	SubtitleFormat::save(filename, encoding);
	
	std::ofstream file(filename.c_str());
	if(!file)
	{
		throw SubtitleException("SubtitleMicroDVD", _("I can't open this file."));
	}

	// TODO : change!
#warning "fixme > FPS convert"
	double fps = 23.976;
	
	SubtitleColumnRecorder column;
	Glib::ustring text;
	
	Gtk::TreeNodeChildren rows = m_model->children();
	for(Gtk::TreeIter it = rows.begin(); it; ++it)
	{
		SubtitleTime start((*it)[column.start]);
		SubtitleTime end((*it)[column.end]);

		std::string text = utf8_to_charset((*it)[column.text]);

		//find_and_replace(text, "\n", "|");
		//find_and_replace(text, "\N", "|");
		
		file << "{"
			<< (unsigned int)(start.totalmsecs / fps)
			<< "}{"
			<< (unsigned int)(end.totalmsecs / fps)
			<< "}"
			<< text
			<< std::endl;
	}
	
	file.close();

	debug_msg("SubtitleMicroDVD::save > finish");
	return true;
}

==> subtitleeditor-0.12.4.tar.gz: subtitleeditor-0.12.4/src/SubtitleMicroDVD.cc <==
/*
 *	subtitle editor
 *
 *	http://kitone.free.fr/subtitleeditor/
 *
 *	Copyright @ 2005-2006, kitone
 *
 *	Contact: kitone at free dot fr
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public
 *	License as published by the Free Software Foundation; either
 *	version 2 of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public
 *	License along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 *
 *	See gpl.txt for more information regarding the GNU General Public License.
 *
 *
 *	\file
 *	\brief 
 *	\author kitone (kitone at free dot fr)
 */

#include "SubtitleMicroDVD.h"
#include <iostream>
#include <fstream>
#include <glibmm/ustring.h>
#include "utility.h"
#include "RegEx.h"

/*
 *
 */
Glib::ustring SubtitleMicroDVD::get_name()
{
	return "MicroDVD";
}

/*
 *
 */
Glib::ustring SubtitleMicroDVD::get_extension()
{
	return "sub";
}

/*
 *
 */
bool SubtitleMicroDVD::check(const std::string &line)
{
	static RegEx ex("^\\{[0-9]+\\}\\{[0-9]+\\}");

	return ex.exec(line);
}


/*
 *
 */
SubtitleMicroDVD::SubtitleMicroDVD(Document* doc)
:SubtitleFormat(doc)
{
	se_debug(SE_DEBUG_LOADER | SE_DEBUG_SAVER);
}

/*
 *
 */
SubtitleMicroDVD::~SubtitleMicroDVD()
{
	se_debug(SE_DEBUG_LOADER | SE_DEBUG_SAVER);
}


/*
 *
 */
bool SubtitleMicroDVD::open(const Glib::ustring &filename, const Glib::ustring &encoding)
{
	se_debug(SE_DEBUG_LOADER);


	SubtitleFormat::open(filename, encoding);
	
	std::ifstream file(filename.c_str());

	if(!file)
	{
		throw SubtitleException("SubtitleMicroDVD", _("I can't open this file."));
	}

	int start=0, end=0;

#warning "fixme > FPS convert"

	double framerate = 23.976;
	
	std::string line;
	while(!file.eof() && std::getline(file, line))
	{
		if(sscanf(line.c_str(), "{%d}{%d}", &start, &end) > 0)
		{
			std::string::size_type a = line.find('}');
			std::string::size_type b = line.find('}', a+1);
			
			std::string text = line.substr(b+1, line.size());

			SubtitleModifier subtitle(m_subtitleModel->append());

			subtitle.set_start_and_end( 
					SubtitleTime::frame_to_time(start, framerate),
					SubtitleTime::frame_to_time(end, framerate));

			Glib::ustring txt = check_end_char(charset_to_utf8(text));

			characters_to_newline(txt, "|");
			
			subtitle.set_text(txt);
		}
	}

	file.close();

	return true;
}

/*
 *
 */
bool SubtitleMicroDVD::save(const Glib::ustring &filename, const Glib::ustring &encoding)
{
	se_debug(SE_DEBUG_SAVER);

	SubtitleFormat::save(filename, encoding);
	
	std::ofstream file(filename.c_str());
	if(!file)
	{
		throw SubtitleException("SubtitleMicroDVD", _("I can't open this file."));
	}

	// TODO : change!
#warning "fixme > framerate use Config"
	double framerate = 23.976;

	//file << "{0}{0}23.976" << std::endl;

	Glib::ustring text;
	
	Gtk::TreeNodeChildren rows = m_subtitleModel->children();
	for(Gtk::TreeIter it = rows.begin(); it; ++it)
	{
		SubtitleModifier subtitle(it);

		SubtitleTime start = subtitle.get_start();
		SubtitleTime end = subtitle.get_end();

		Glib::ustring text = subtitle.get_text();

		newline_to_characters(text, "|");

		file << "{"
			<< SubtitleTime::time_to_frame(start, framerate)
			<< "}{"
			<< SubtitleTime::time_to_frame(end, framerate)
			<< "}"
			<< utf8_to_charset(text)
			<< std::endl;
	}
	
	file.close();

	return true;
}
